From 7a705bedfa4fa0b433cd43e1a9d5da1f0eea12e0 Mon Sep 17 00:00:00 2001
From: Ere Maijala <ere.maijala@helsinki.fi>
Date: Mon, 14 Mar 2016 16:49:50 +0200
Subject: [PATCH] Don't try to check save statuses if the user is not logged
 in.

---
 themes/bootstrap3/js/check_save_statuses.js | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/themes/bootstrap3/js/check_save_statuses.js b/themes/bootstrap3/js/check_save_statuses.js
index bfa790537b0..c30b63fc6f5 100644
--- a/themes/bootstrap3/js/check_save_statuses.js
+++ b/themes/bootstrap3/js/check_save_statuses.js
@@ -1,6 +1,9 @@
 /*global htmlEncode, VuFind */
 
 function checkSaveStatuses(container) {
+  if (!userIsLoggedIn) {
+    return;
+  }
   if (typeof(container) == 'undefined') {
     container = $('body');
   }
@@ -1,6 +1,9 @@
-/*global htmlEncode, VuFind */
+/*global htmlEncode, VuFind, userIsLoggedIn */
 
 function checkSaveStatuses(container) {
-- 
GitLab